@@ -1,10 +1,10 @@
 /*
- * File:				config.h
- * Created:				March 2008
- * Created by:			Axel von Bertoldi
- * Last Modified:		August 2008
- * Last Modified by:	Axel von Bertoldi
- * (C) 2005-2008		Axel von Bertoldi
+ * File:                config.h
+ * Created:             March 2008
+ * Created by:          Axel von Bertoldi
+ * Last Modified:       April 2009
+ * Last Modified by:    Axel von Bertoldi
+ * (C) 2005-2008        Axel von Bertoldi
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -29,13 +29,13 @@
 #include <glib/gi18n.h>
 
 #define APP_NAME         "file-browser-applet"
-#define ICON_BUTTON_SIZE 24	/* Damn! Hard-coded pixels! */
-#define GLADEUI_PATH	 "/usr/share/file-browser-applet/glade/file-browser-applet.glade"
-#define PIXMAP_PATH	     "/usr/share/pixmaps/"
-#define LOCALEDIR		 "/usr/share/locale/"
+#define ICON_BUTTON_SIZE 24 /* Damn! Hard-coded pixels! */
+#define BUILDER_UI_PATH  "/usr/share/file-browser-applet/builder/file-browser-applet.ui"
+#define PIXMAP_PATH      "/usr/share/pixmaps/"
+#define LOCALEDIR        "/usr/share/locale/"
 
 #define DEBUG 0
-#define ENABLE_HELP_DOC
+/* #undef ENABLE_HELP_DOC */
 #define ENABLE_CONTEXT_MENU
 #define LIBGTKHOTKEY_FOUND
 
