@@ -1,10 +1,10 @@
 /*
- * File:				vfs.h
- * Created:				February 2008
- * Created by:			Axel von Bertoldi
- * Last Modified:		August 2008
- * Last Modified by:	Axel von Bertoldi
- * (C) 2005-2008		Axel von Bertoldi
+ * File:                vfs.h
+ * Created:             February 2008
+ * Created by:          Axel von Bertoldi
+ * Last Modified:       August 2008
+ * Last Modified by:    Axel von Bertoldi
+ * (C) 2005-2008        Axel von Bertoldi
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -30,32 +30,32 @@
 
 /******************************************************************************/
 enum {
-	ARG_APP,
-	ARG_FILE,
+    ARG_APP,
+    ARG_FILE,
     ARGS_SIZE,
 };
 /******************************************************************************/
 typedef struct _VfsFileInfo VfsFileInfo;
 /******************************************************************************/
 struct _VfsFileInfo {
-	gchar		*display_name; /* need to free this */
-	gchar		*file_name; /* need to free this */
-	GtkWidget	*icon; /* don't need to free this */
-	gboolean	is_executable;
+    gchar       *display_name; /* need to free this */
+    gchar       *file_name; /* need to free this */
+    GtkWidget   *icon; /* don't need to free this */
+    gboolean    is_executable;
 };
 /******************************************************************************/
-gboolean	vfs_file_is_executable		(const gchar *file_name);
-gboolean	vfs_file_is_desktop			(const gchar *file_name);
-gboolean	vfs_file_is_directory		(const gchar *file_name);
-gboolean	vfs_file_exists				(const gchar *file_name);
+gboolean    vfs_file_is_executable   (const gchar *file_name);
+gboolean    vfs_file_is_desktop      (const gchar *file_name);
+gboolean    vfs_file_is_directory    (const gchar *file_name);
+gboolean    vfs_file_exists          (const gchar *file_name);
 
-gchar*		vfs_get_dir_listings		(GPtrArray *files, GPtrArray *dirs, gboolean show_hidden, const gchar *path);
-GList*		vfs_get_all_mime_applications (const gchar *file_name);
-GtkWidget*	vfs_get_icon_for_file		(const gchar *file_name);
+gchar*      vfs_get_dir_listings        (GPtrArray *files, GPtrArray *dirs, gboolean show_hidden, gboolean show_thumbnail, const gchar *path);
+GList*      vfs_get_all_mime_applications (const gchar *file_name);
+GtkWidget*  vfs_get_icon_for_file       (const gchar *file_name);
 
-gboolean	vfs_launch_application		(const gchar *const*args);
-gboolean	vfs_file_do_default_action	(const gchar *file_name);
-void	 	vfs_file_trash				(gchar *file_name);
+gboolean    vfs_launch_application      (const gchar *const*args);
+gboolean    vfs_file_do_default_action  (const gchar *file_name);
+void        vfs_file_trash              (const gchar *file_name);
 /******************************************************************************/
 
 #endif
